==> storify-0.0.4.tgz: package/lib/user.js <==
var path = require('path')
  , Story = require('./story');

var User = function(s, user) {
  var self = this;
  self.info = {};
  Object.keys(user).forEach(function(p) {
    self[p] = self.info[p] = user[p];
  });
  
  this._api = s;
};

User.prototype = {
  
  getStory: function(slug, fn) {
    var self = this
      , route = path.join('/stories', this.username, slug);
    
    return self.get(route, {}, function(e, res) {
      fn(e, e ? null : new Story(self, res.content));
    });
  },

  getStories: function(params, fn) {
    var self = this;
    
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    return self.get('/stories', params, function(e, res) {
      var stories = [];
      res.content.stories.forEach(function(story) {
        story.author = self;
        stories.push(new Story(self._api, story));
      });
      fn(e, stories);
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'get';
    params.username = this.username;
    params._token = this._token;
    
    return this._api.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'post';
    params.username = this.username;
    params._token = this._token;
    
    return this._api.request(route, params, options, fn);
  }

};

module.exports = User;

==> storify-0.0.5.tgz: package/lib/user.js <==
var path = require('path')
  , Story = require('./story');

var User = function(s, user) {
  var self = this;
  self.info = {};
  Object.keys(user).forEach(function(p) {
    self[p] = self.info[p] = user[p];
  });
  
  this._api = s;
};

User.prototype = {
  
  getStory: function(slug, params, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    var self = this
      , route = path.join('/stories', this.username, slug);
    
    return self.get(route, params, function(e, res) {
      fn(e, e ? null : new Story(self, res.content));
    });
  },

  getStories: function(params, fn) {
    var self = this;
    
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    return self.get('/stories', params, function(e, res) {
      var stories = [];
      res.content.stories.forEach(function(story) {
        story.author = self;
        stories.push(new Story(self._api, story));
      });
      fn(e, stories);
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'get';
    params.username = this.username;
    params._token = this._token;
    
    return this._api.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'post';
    params.username = this.username;
    params._token = this._token;
    
    return this._api.request(route, params, options, fn);
  }

};

module.exports = User;
